'use strict';

exports.__esModule = true;
var requestAnimationFrame = void 0;
var cancelAnimationFrame = void 0;

if (typeof document === 'undefined') {
  // For Node.js
  exports.requestAnimationFrame = requestAnimationFrame = function requestAnimationFrame() {};
  exports.cancelAnimationFrame = cancelAnimationFrame = function cancelAnimationFrame() {};
} else {
  (function () {
    var vendors = ['ms', 'moz', 'webkit', 'o'];
    var lastTime = 0;

    exports.requestAnimationFrame = requestAnimationFrame = window.requestAnimationFrame;
    exports.cancelAnimationFrame = cancelAnimationFrame = window.cancelAnimationFrame;

    for (var x = 0; x < vendors.length && !requestAnimationFrame; x++) {
      exports.requestAnimationFrame = requestAnimationFrame = window[vendors[x] + 'RequestAnimationFrame'];
      exports.cancelAnimationFrame = cancelAnimationFrame = window[vendors[x] + 'CancelAnimationFrame'] || window[vendors[x] + 'CancelRequestAnimationFrame'];
    }

    if (!requestAnimationFrame) {
      exports.requestAnimationFrame = requestAnimationFrame = function requestAnimationFrame(callback) {
        var currTime = new Date().getTime();
        var timeToCall = Math.max(0, 16 - (currTime - lastTime));
        var id = window.setTimeout(function () {
          callback(currTime + timeToCall);
        }, timeToCall);
        lastTime = currTime + timeToCall;
        return id;
      };
    }

    if (!cancelAnimationFrame) {
      exports.cancelAnimationFrame = cancelAnimationFrame = function cancelAnimationFrame(id) {
        return clearTimeout(id);
      };
    }
  })();
}

exports.requestAnimationFrame = requestAnimationFrame;
exports.cancelAnimationFrame = cancelAnimationFrame;